Приступая к работе
------------------

Для полноценного функционирования утилиты необходимо, чтобы в системе был установлен интерпритатор языка Python
не ниже версии ``3.6.9``, а также утилиты ``python-pip`` и ``python-venv`` 
(если подразумевается работа с более чем одной организацией).

.. note::

    Данное приложение разрабатывалось как кроссплатформенное.
    Достоверно известно, что в системах FreeBSD, Mac OS X и Linux успешно функционирует,
    но на платформе Windows тестирование не проводилось.

.. toctree::

    usage